/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * Based on arch/arm/include/asm/system_misc.h
 *
 * Copyright (C) 2012 ARM Ltd.
 */
#ifndef __ASM_SYSTEM_MISC_H
#define __ASM_SYSTEM_MISC_H

#ifndef __ASSEMBLY__

#include <linux/compiler.h>
#include <linux/linkage.h>
#include <linux/irqflags.h>
#include <linux/signal.h>
#include <linux/ratelimit.h>
#include <linux/reboot.h>

struct pt_regs;

void die(const char *msg, struct pt_regs *regs, int err);

struct siginfo;
void arm64_notify_die(const char *str, struct pt_regs *regs,
		      int signo, int sicode, void __user *addr,
		      int err);

void hook_debug_fault_code(int nr, int (*fn)(unsigned long, unsigned int,
					     struct pt_regs *),
			   int sig, int code, const char *name);

struct mm_struct;
extern void __show_regs(struct pt_regs *);

extern void (*arm_pm_restart)(enum reboot_mode reboot_mode, const char *cmd);
extern const char *hardware_name;

#ifdef CONFIG_ARCH_HISI
extern char * (*arch_read_hardware_id)(void);
#endif

#include <linux/adc.h>

#define CPU_BOARD_ID_BIT 1
#define CPU_MIN_VOL 100

static inline int get_cpu_id(void)
{
	int voltage_id = CPU_MIN_VOL;

	voltage_id = lpm_adc_get_value(CPU_BOARD_ID_BIT);
	if (voltage_id < 0) {
		printk(KERN_ERR "[%s] get voltage_id failed! voltage_id = %d \n", __func__, voltage_id);
	}

	if ((voltage_id >= CPU_MIN_VOL) || (voltage_id < 0)) {
		//取值为1，表示为121/B版本
		return 1;
	} else {
		//取值为0，表示为120/A版本
		return 0;
	}
}
#endif	/* __ASSEMBLY__ */

#endif	/* __ASM_SYSTEM_MISC_H */
